@@ -22,6 +22,16 @@ test_that("model must contain a known mode (#160)", {
   })
 })
 
+test_that("prompt on spec without a loaded implementation (#174)", {
+  mod <- parsnip::bag_tree() %>%
+    parsnip::set_mode("regression")
+
+  workflow <- workflow()
+
+  expect_snapshot(error = TRUE, add_model(workflow, mod))
+  expect_snapshot(error = TRUE, workflow(spec = mod))
+})
+
 test_that("cannot add two models", {
   mod <- parsnip::linear_reg()
   mod <- parsnip::set_engine(mod, "lm")
